`timescale 1ns / 1ps

module DigitalWatch(reset, clk, sw0, sw1,sw2, sw3, hourFNDSel2, hourFNDSel1, minFNDSel2, minFNDSel1, secFNDSel2, secFNDSel1, 
                    hourFND, minFND, secFND, alarm_out, alarm_on, mode_out, set_pos_out);
    input reset, clk;
    input sw0, sw1, sw2, sw3;
    
    output hourFNDSel2,hourFNDSel1;
    output minFNDSel2, minFNDSel1;
    output secFNDSel2, secFNDSel1;
    output [6:0] hourFND, minFND, secFND;
    output [2:0] alarm_out;
    output [1:0] alarm_on;
    output [1:0] mode_out;
    output [2:0] set_pos_out;
    
    wire clk1hz, clk2hz, clk100hz;
    wire [1:0] mode;
    wire [2:0] set_pos;
    wire [5:0] clk_sec;
    wire [5:0] clk_min;
    wire [4:0] clk_hour;
    wire [6:0] tl_mmsecwire;
    wire [5:0] tl_secwire;
    wire [5:0] tl_minwire;
    wire [5:0] al_secwire;
    wire [5:0] al_minwire;
    wire [4:0] al_hourwire;
    
    MasterSelect MA0(
        .reset          (reset),
        .clk            (clk),
        .sw0            (sw0),
        .sw1            (sw1),
        .clk1hz_out     (clk1hz),
        .clk2hz_out     (clk2hz),
        .clk100hz_out   (clk100hz),
        .mode_out       (mode),
        .set_pos_out    (set_pos)
        );
        
    DigitalClock DC0(
        .reset      (reset),
        .clk        (clk),
        .clk1hz     (clk1hz),
        .clk2hz     (clk2hz),
        .blink      (blink),
        .sw2        (sw2),
        .mode       (mode),
        .set_pos    (set_pos),
        .sec_out    (clk_sec),
        .min_out    (clk_min),
        .hour_out   (clk_hour)
        );
    TimerLogic  TL0(
        .reset      (reset),
        .clk100hz   (clk100hz),
        .sw1        (sw1),
        .sw2        (sw2),
        .mode       (mode_out),
        .mmsec_out  (tl_mmsecwire),
        .sec_out    (tl_secwire),
        .min_out    (tl_minwire)
        );
    AlarmLogic  AL0(
        .reset      (reset),
        .clk        (clk),
        .clk2hz     (clk2hz),
        .clk100hz   (clk100hz),
        .blink      (blink),
        .sw2        (sw2),
        .sw3        (sw3),
        .mode       (mode),
        .set_pos    (set_pos),
        .clk_min    (clk_min),
        .clk_hour   (clk_hour),
        .sec_out    (al_secwire),
        .min_out    (al_minwire),
        .hour_out   (al_hourwire),
        .alarm_out  (alarm_out),
        .alarm_on   (alarm_on)
        );
     FNDDisplay FD0(
        .reset      (reset),
        .clk        (clk),
        .clk2hz     (clk2hz),
        .clk100hz   (clk100hz),
        .sw2        (sw2),
        .mode       (mode),
        .set_pos    (set_pos),
        .dc_sec     (clk_sec),
        .dc_min    (clk_min),
        .dc_hour    (clk_hour),
        .tl_mmsec   (tl_mmsecwire),
        .tl_sec     (tl_secwire),
        .tl_min     (tl_minwire),
        .al_sec     (al_secwire),
        .al_min     (al_minwire),
        .al_hour    (al_hourwire),
        .hourFNDSel2 (hourFNDSel2),
        .hourFNDSel1 (hourFNDSel1),
        .minFNDSel2  (minFNDSel2),
        .minFNDSel1  (minFNDSel1),
        .secFNDSel2  (secFNDSel2),
        .secFNDSel1  (secFNDSel1),
        .blink_out    (blink),
        .hourFND     (hourFND),
        .minFND      (minFND),
        .secFND      (secFND)
        );
        assign mode_out = mode;
        assign set_pos_out = set_pos;
endmodule